@@ -1,7 +1,7 @@
 from multiprocessing import Process, cpu_count, get_context
 from multiprocessing.context import Process as ProcessType
 import time
-from types import FunctionType
+from types import FunctionType, MethodType
 import warnings
 
 
@@ -42,7 +42,7 @@ class MultiProcess:
         # TODO! Expected type 'FunctionType', got '(a_string: Any) -> None' instead
 
         # error handling
-        if not isinstance(func, FunctionType):
+        if not isinstance(func, FunctionType) and not isinstance(func, MethodType):
             raise TypeError("Wrong type of func, must be a FunctionType!")
         if not isinstance(args, tuple):
             raise TypeError("Wrong type of args, must be a tuple!")
